package jetbrains.buildServer.genStatus;

import jetbrains.buildServer.controllers.BaseController;
import jetbrains.buildServer.serverSide.SBuildServer;
import jetbrains.buildServer.serverSide.SBuildType;
import jetbrains.buildServer.web.openapi.WebControllerManager;
import jetbrains.buildServer.web.openapi.WebResourcesManager;
import org.springframework.web.servlet.ModelAndView;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.io.PrintWriter;
import java.util.Iterator;

/**
 * @author Yegor Yarko
 *         Date: 10.07.2007
 */
public class GenStatusController extends BaseController {
  private static final String GEN_STATUS_URL_PATH = "/genStatus.html";

  public GenStatusController(final SBuildServer server, final WebResourcesManager resourcesManager, final WebControllerManager controllerManager) {
    super(server);
    controllerManager.registerController(GEN_STATUS_URL_PATH, this);
  }

  public ModelAndView doHandle(final HttpServletRequest request, final HttpServletResponse response) throws Exception {
    boolean globalStatus = true;
    Iterator it = myServer.getProjectManager().getAllBuildTypes().iterator();
    while (it.hasNext()) {
      SBuildType buildType = (SBuildType) it.next();
      if (buildType.getLastFinished() != null) {
        boolean lastBuildStatus = buildType.getLastFinished().getStatusDescriptor().getStatus().isSuccessful();
        globalStatus = globalStatus && lastBuildStatus;
      }
    }
    String responseText;
    if (globalStatus) {
      responseText = "green";
    } else {
      responseText = "red";
    }

    try {
      response.setContentType("text/html");
      final PrintWriter writer = response.getWriter();

      writer.print(responseText);

      writer.flush();
      writer.close();
    }
    catch (IOException e) {
      e.printStackTrace();
    }
    return null;
  }
}
